@@ -1,7 +1,7 @@
 use std::convert::TryInto;
 
 use clap::ArgMatches;
-use miette::{IntoDiagnostic, Result};
+use miette::Result;
 use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
 
 use crate::{current_dir, get_vcs};
@@ -19,9 +19,7 @@ fn run(matches: &ArgMatches) -> Result<()> {
     let mut vcs = get_vcs(is_local, &current_dir)?;
     let input_toml = external::read_toml(current_dir)?;
 
-    let output_toml: String = read_from_toml_or_else_vcs(&input_toml, &mut vcs)?
-        .try_into()
-        .into_diagnostic()?;
+    let output_toml: String = read_from_toml_or_else_vcs(&input_toml, &mut vcs)?.try_into()?;
 
     mit_commit_message_lints::console::to_be_piped(output_toml.trim());
 
